pub struct Distribution1 {
pub values: Vec<f64>,
pub sample_rates: Vec<u32>,
pub statistic: i32,
}Fields
values: Vec<f64>sample_rates: Vec<u32>statistic: i32Implementations
Sourceimpl Distribution1
impl Distribution1
Sourcepub fn statistic(&self) -> StatisticKind
pub fn statistic(&self) -> StatisticKind
Returns the enum value of statistic, or the default if the field is set to an invalid enum value.
Sourcepub fn set_statistic(&mut self, value: StatisticKind)
pub fn set_statistic(&mut self, value: StatisticKind)
Sets statistic to the provided enum value.