pub struct Distribution2 {
pub samples: Vec<DistributionSample>,
pub statistic: i32,
}Fields
samples: Vec<DistributionSample>statistic: i32Implementations
Sourceimpl Distribution2
impl Distribution2
Sourcepub fn statistic(&self) -> StatisticKind
pub fn statistic(&self) -> StatisticKind
Returns the enum value of statistic, or the default if the field is set to an invalid enum value.
Sourcepub fn set_statistic(&mut self, value: StatisticKind)
pub fn set_statistic(&mut self, value: StatisticKind)
Sets statistic to the provided enum value.